;*************************************************************
;Adresy i krotki opis procedur dostepnych w programie monitora
;systemu edukacyjnego AVT-2250 dla procesorow rodziny MCS-51
;*************************************************************

;uzywane skroty:
;	we: parametry wejsciowe przed wywolaniem procedury
;	wy: parametry wyjsciowe lub/i efekt dzialania po
;	    jej zakonczeniu
;    traci: lista rejestrow ktorych zawartosc zostaje 
;	    zmieniona podczas wykonywania danej procedury

;=============================================================
;Opis: zamienia liczbe z akumulatora na 2 znaki ASCII w B.A
;we: Acc - liczba (np. 4Fh)
;wy: B.A - 2 znaki ASCII umieszczone w rejesteach: B i Acc 
;          np. dla naszego przykladu B='4'(52),Acc='F'(70)

HEXASCII	equ	0235h

;=============================================================
;Opis: wyswietla akumulator na wyswietlaczu jako 2 znaki 0..9,A..F
;      pozycja pierwszej cyfry okreslona jest w rejestrze B
;we: Acc - liczba do wyswietlenia, B - pozycja (1...7 -> DL1...7)
;traci: R0, Acc, B

A2HEX		equ	024Eh

;=============================================================
;Opis: wyswietla DPTR na wyswietlaczu jako 4 znaki 0..9,A..F
;      pozycja pierwszej cyfry okreslona jest w rejestrze B
;we: Acc - liczba do wyswietlenia, B - pozycja (1...5 -> DL1...5)
;traci: R0, A, B

DPTR4HEX	equ	025Fh

;==============================================================
;Opis: czysci wyswietlacz - wpisuje zera do zmiennych DL1...DL8
;we: -
;wy: wpisanie 00h do DL1...DL8
;traci: R0 i R7

CLS		equ	0274h

;==============================================================
;Opis: wypisuje pseudo-tekst na wyswietlaczu zlozony ze znakow
;      zdefiniowanych w zbiorze CONST.INC, a zakonczony zerem 
;      np. _A,_B,_C,0 -> wyswietli "ABC"; 
;we: DPTR: wskazuje na pseudo-tekst, B - pozycja 1 znaku
;traci: DPTR, A, R0

TEXT		equ	0285h

;=============================================================
;Opis: procedura opoznienia w zakresie ok. 2...500 milisekund
;we: A - opoznienie = wpisana liczba * 1,95 ms (okolo)
;traci: A

DELAY		equ	0295h

;=============================================================
;Opis: procedura oczekiwania na znak z portu szeregowego;
;      przed wywolaniem jej nalezy odpowiednio skonfigurowac
;      rejestry SMOD oraz okreslic predkosc transmisji
;we: -
;wy: gdy C=0 to zakonczenie poprawne i w Acc odebrany znak;
;    gdy C=1 to przekroczenie maksymalnego czasu oczekiwania
;    okreslonego w zmiennej 'overconst' (patrz plik CONST.INC)
;zmienia: zeruje znacznik RI, sama ustawia znacznik REN (odbiornika)

INRS		equ	02A5h

;=============================================================
;Opis: procedura wyslania znaku przez port szeregowy;
;      czeka na zakonczenie wyslania znaku przez procesor
;we: A - znak do wyslania
;zmienia: zeruje znacznik TI, po zakonczeniu ustawia znacznik REN

OUTRS		equ	02B9h

;=============================================================
;Opis: zeruje zbufor klawiatury (klawisz=0), po czym czeka na
;      nacisniecie dowolnego klawisza do skutku ;
;      uwaga: nie korzysta ze zmiennej 'overtime'
;wy: A - kod klawisza

CONIN		equ	02C5h

;=============================================================
;Opis: procedura czekania na 2 znaki ASCII z portu szeregowego
;      a nastepnie zamiana ich na liczbe w akumulatorze
;we: dwa znaki do portu szeregowego (0...9,A...F)
;wy: jesli C=0 to w Acc liczba (np. 8Eh przez zlozenie znakow '8' i 'E')
;    jesli C=1 to blad przeterminowania

INACCRS		equ	02F2h

;=============================================================
;Opis: procedura wprowadzenia z klawiatury cyfry szesnastkowej
;      i umieszczenie jej w akumulatorze z wyswietleniem jej
;      na pozycji podanej w rejestrze B
;we: B - pozycja na wyswietlaczu (1...8)
;    wcisniecie klawisza: 0...9,A...F;
;wy: A - wprowadzona liczba (0...15)
;traci: R0

GETDIGIT	equ	0379h

;=============================================================
;Opis: procedura wprowadzenia z klawiatury 8-bitowej liczby 
;      w postaci hexadecymalnej i umieszczenie jej w akumulatorze 
;      z wyswietleniem na pozycji podanej w rejestrze B
;we: wcisniecie 2 klawiszy: 0...9, A...F; 
;    B - pozycja pierwszego znaku na wyswietlaczu (1...7)
;wy: A - liczba (np. 64h po wcisnieciu klawiszy '6' i '4')
;traci: R0

GETACC		equ	03A7h

;=============================================================
;Opis: procedura wprowadzenia z klawiatury 16-bitowej liczby
;      w postaci heksadecymalnej i umieszczenie jej w DPTR
;      z wyswietleniem na pozycji podanej w rejestrze B
;we: wcisniecie 4 klawiszy 0...9,A...F
;    B - pozycja pierwszego znaku na wyswietlaczu (1...5)
;wy: DPTR (DPH:MsB,DPL:LsB) - wprowadzona liczba 
;    (np. 12A9h po wcisnieciu klawiszy '1','2','A' i '9')
;traci: R0

GETDPTR		equ	03B9h

;=============================================================


